summaryrefslogtreecommitdiffstats
path: root/kresources/kolab/shared
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/kolab/shared')
-rw-r--r--kresources/kolab/shared/kmailconnection.cpp16
-rw-r--r--kresources/kolab/shared/kmailconnection.h9
-rw-r--r--kresources/kolab/shared/kolabbase.cpp40
-rw-r--r--kresources/kolab/shared/kolabbase.h24
-rw-r--r--kresources/kolab/shared/resourcekolabbase.cpp14
-rw-r--r--kresources/kolab/shared/resourcekolabbase.h10
-rw-r--r--kresources/kolab/shared/subresource.cpp6
-rw-r--r--kresources/kolab/shared/subresource.h10
8 files changed, 65 insertions, 64 deletions
diff --git a/kresources/kolab/shared/kmailconnection.cpp b/kresources/kolab/shared/kmailconnection.cpp
index 5b2921b94..d9ffd98d5 100644
--- a/kresources/kolab/shared/kmailconnection.cpp
+++ b/kresources/kolab/shared/kmailconnection.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -82,7 +82,7 @@ bool KMailConnection::connectToKMail()
// someone, probably ourselves, already offers the interface, if not stop here
const QCStringList services = kapp->dcopClient()->registeredApplications();
for ( uint i = 0; i < services.count(); ++i ) {
- if ( services[i].find( "anonymous" ) == 0 ) // querying anonymous-XXXXX deadlocks as well, what are those anyway?
+ if ( services[i].tqfind( "anonymous" ) == 0 ) // querying anonymous-XXXXX deadlocks as well, what are those anyway?
continue;
const QCStringList objs = kapp->dcopClient()->remoteObjects( services[i] );
if ( objs.tqcontains( dcopObjectId ) ) {
@@ -97,8 +97,8 @@ bool KMailConnection::connectToKMail()
} else {
TQString error;
int result = KDCOPServiceStarter::self()->
- findServiceFor( "DCOP/ResourceBackend/IMAP", TQString::null,
- TQString::null, &error, &dcopService );
+ findServiceFor( "DCOP/ResourceBackend/IMAP", TQString(),
+ TQString(), &error, &dcopService );
if ( result != 0 ) {
kdError(5650) << "Couldn't connect to the IMAP resource backend\n";
// TODO: You might want to show "error" (if not empty) here,
@@ -295,11 +295,11 @@ bool KMailConnection::kmailUpdate( const TQString& resource,
}
bool KMailConnection::kmailAddSubresource( const TQString& resource,
- const TQString& parent,
+ const TQString& tqparent,
const TQString& contentsType )
{
return connectToKMail()
- && mKMailIcalIfaceStub->addSubresource( resource, parent, contentsType )
+ && mKMailIcalIfaceStub->addSubresource( resource, tqparent, contentsType )
&& mKMailIcalIfaceStub->ok();
}
diff --git a/kresources/kolab/shared/kmailconnection.h b/kresources/kolab/shared/kmailconnection.h
index 3cf5b826f..b7befb4de 100644
--- a/kresources/kolab/shared/kmailconnection.h
+++ b/kresources/kolab/shared/kmailconnection.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -50,6 +50,7 @@ class ResourceKolabBase;
*/
class KMailConnection : public TQObject, public DCOPObject {
Q_OBJECT
+// TQ_OBJECT
K_DCOP
// These are the methods called by KMail when the resource changes
@@ -107,7 +108,7 @@ public:
bool kmailTriggerSync( const TQString& contentsType );
bool kmailAddSubresource( const TQString& resource,
- const TQString& parent,
+ const TQString& tqparent,
const TQString& contentsType );
bool kmailRemoveSubresource( const TQString& resource );
diff --git a/kresources/kolab/shared/kolabbase.h b/kresources/kolab/shared/kolabbase.h
index ba6a1c85a..d4621c722 100644
--- a/kresources/kolab/shared/kolabbase.h
+++ b/kresources/kolab/shared/kolabbase.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -54,8 +54,8 @@ class KolabBase {
public:
struct Email {
public:
- Email( const TQString& name = TQString::null,
- const TQString& email = TQString::null )
+ Email( const TQString& name = TQString(),
+ const TQString& email = TQString() )
: displayName( name ), smtpAddress( email )
{
}
@@ -66,7 +66,7 @@ public:
enum Sensitivity { Public = 0, Private = 1, Confidential = 2 };
- explicit KolabBase( const TQString& timezone = TQString::null );
+ explicit KolabBase( const TQString& timezone = TQString() );
virtual ~KolabBase();
// Return a string identifying this type
@@ -94,9 +94,9 @@ public:
virtual bool hasPilotSyncId() const;
virtual unsigned long pilotSyncId() const;
- virtual void setPilotSyncStatus( int status );
- virtual bool hasPilotSyncStatus() const;
- virtual int pilotSyncStatus() const;
+ virtual void setPilotSynctqStatus( int status );
+ virtual bool hasPilotSynctqStatus() const;
+ virtual int pilotSynctqStatus() const;
// String - Date conversion methods
static TQString dateTimeToString( const TQDateTime& time );
@@ -116,7 +116,7 @@ public:
bool load( const TQString& xml );
bool load( TQFile& xml );
- // Load this QDomDocument
+ // Load this TQDomDocument
virtual bool loadXML( const TQDomDocument& xml ) = 0;
// Serialize this object to an XML string
@@ -167,9 +167,9 @@ protected:
TQString mTimeZoneId;
// KPilot synchronization stuff
- bool mHasPilotSyncId, mHasPilotSyncStatus;
+ bool mHasPilotSyncId, mHasPilotSynctqStatus;
unsigned long mPilotSyncId;
- int mPilotSyncStatus;
+ int mPilotSynctqStatus;
};
}
diff --git a/kresources/kolab/shared/resourcekolabbase.cpp b/kresources/kolab/shared/resourcekolabbase.cpp
index 26ef00db6..cf81f4518 100644
--- a/kresources/kolab/shared/resourcekolabbase.cpp
+++ b/kresources/kolab/shared/resourcekolabbase.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -199,10 +199,10 @@ bool ResourceKolabBase::connectToKMail() const
}
bool ResourceKolabBase::kmailAddSubresource( const TQString& resource,
- const TQString& parent,
+ const TQString& tqparent,
const TQString& contentsType )
{
- return mConnection->kmailAddSubresource( resource, parent, contentsType );
+ return mConnection->kmailAddSubresource( resource, tqparent, contentsType );
}
bool ResourceKolabBase::kmailRemoveSubresource( const TQString& resource )
@@ -257,7 +257,7 @@ TQString ResourceKolabBase::findWritableResource( const ResourceType &type,
KMessageBox::error( 0, errorText );
mErrorCode = NoWritableFound;
- return TQString::null;
+ return TQString();
}
if ( possible.count() == 1 )
// Just one found
@@ -274,7 +274,7 @@ TQString ResourceKolabBase::findWritableResource( const ResourceType &type,
if ( chosenLabel.isEmpty() ) {
// cancelled
mErrorCode = UserCancel;
- return TQString::null;
+ return TQString();
}
return possible[chosenLabel];
}
diff --git a/kresources/kolab/shared/resourcekolabbase.h b/kresources/kolab/shared/resourcekolabbase.h
index 565be2675..d16f2a576 100644
--- a/kresources/kolab/shared/resourcekolabbase.h
+++ b/kresources/kolab/shared/resourcekolabbase.h
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -162,7 +162,7 @@ protected:
const TQStringList& attachmentNames = TQStringList(),
const TQStringList& deletedAttachments = TQStringList() );
- bool kmailAddSubresource( const TQString& resource, const TQString& parent,
+ bool kmailAddSubresource( const TQString& resource, const TQString& tqparent,
const TQString& contentsType );
bool kmailRemoveSubresource( const TQString& resource );
@@ -172,7 +172,7 @@ protected:
/// If only one of these is writable, return that. Otherwise return null.
TQString findWritableResource( const ResourceType &type,
const ResourceMap& resources,
- const TQString& text = TQString::null );
+ const TQString& text = TQString() );
enum ErrorCode {
NoError,
diff --git a/kresources/kolab/shared/subresource.cpp b/kresources/kolab/shared/subresource.cpp
index a7ffb8f90..7520d275a 100644
--- a/kresources/kolab/shared/subresource.cpp
+++ b/kresources/kolab/shared/subresource.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
diff --git a/kresources/kolab/shared/subresource.h b/kresources/kolab/shared/subresource.h
index de7a92e93..79104a747 100644
--- a/kresources/kolab/shared/subresource.h
+++ b/kresources/kolab/shared/subresource.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -45,7 +45,7 @@ namespace Kolab {
*/
class SubResource {
public:
- // This is just for QMap
+ // This is just for TQMap
SubResource() {}
SubResource( bool active, bool writable, const TQString& label,
@@ -93,7 +93,7 @@ typedef TQMap<TQString, SubResource> ResourceMap;
*/
class StorageReference {
public:
- // Just for QMap
+ // Just for TQMap
StorageReference() {}
StorageReference( const TQString& resource, TQ_UINT32 sernum );
diff --git a/kresources/kolab/shared/kolabbase.cpp b/kresources/kolab/shared/kolabbase.cpp
index 978481072..cb04d12be 100644
--- a/kresources/kolab/shared/kolabbase.cpp
+++ b/kresources/kolab/shared/kolabbase.cpp
@@ -21,11 +21,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -47,7 +47,7 @@ KolabBase::KolabBase( const TQString& tz )
: mCreationDate( TQDateTime::tqcurrentDateTime() ),
mLastModified( TQDateTime::tqcurrentDateTime() ),
mSensitivity( Public ), mTimeZoneId( tz ),
- mHasPilotSyncId( false ), mHasPilotSyncStatus( false )
+ mHasPilotSyncId( false ), mHasPilotSynctqStatus( false )
{
}
@@ -58,7 +58,7 @@ KolabBase::~KolabBase()
void KolabBase::setFields( const KCal::Incidence* incidence )
{
// So far unhandled KCal::IncidenceBase fields:
// mPilotID, mSyncStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );
@@ -233,20 +233,20 @@ unsigned long KolabBase::pilotSyncId() const
return mPilotSyncId;
}
-void KolabBase::setPilotSyncStatus( int status )
+void KolabBase::setPilotSynctqStatus( int status )
{
- mHasPilotSyncStatus = true;
- mPilotSyncStatus = status;
+ mHasPilotSynctqStatus = true;
+ mPilotSynctqStatus = status;
}
-bool KolabBase::hasPilotSyncStatus() const
+bool KolabBase::hasPilotSynctqStatus() const
{
- return mHasPilotSyncStatus;
+ return mHasPilotSynctqStatus;
}
-int KolabBase::pilotSyncStatus() const
+int KolabBase::pilotSynctqStatus() const
{
- return mPilotSyncStatus;
+ return mPilotSynctqStatus;
}
bool KolabBase::loadEmailAttribute( TQDomElement& element, Email& email )
@@ -259,7 +259,7 @@ bool KolabBase::loadEmailAttribute( TQDomElement& element, Email& email )
const TQString tagName = e.tagName();
if ( tagName == "display-name" ) {
- // Quote the text in case it tqcontains commas or other quotable chars.
+ // Quote the text in case it contains commas or other quotable chars.
TQString tusername = KPIM::quoteNameIfNecessary( e.text() );
TQString tname, temail;
@@ -335,7 +335,7 @@ bool KolabBase::loadAttribute( TQDomElement& element )
return true;
}
if ( tagName == "pilot-sync-status" ) {
- setPilotSyncStatus( element.text().toInt() );
+ setPilotSynctqStatus( element.text().toInt() );
return true;
}
break;
@@ -357,8 +357,8 @@ bool KolabBase::saveAttributes( TQDomElement& element ) const
writeString( element, "sensitivity", sensitivityToString( sensitivity() ) );
if ( hasPilotSyncId() )
writeString( element, "pilot-sync-id", TQString::number( pilotSyncId() ) );
- if ( hasPilotSyncStatus() )
- writeString( element, "pilot-sync-status", TQString::number( pilotSyncStatus() ) );
+ if ( hasPilotSynctqStatus() )
+ writeString( element, "pilot-sync-status", TQString::number( pilotSynctqStatus() ) );
return true;
}
@@ -409,12 +409,12 @@ TQDomDocument KolabBase::domTree()
TQString KolabBase::dateTimeToString( const TQDateTime& time )
{
- return time.toString( Qt::ISODate ) + 'Z';
+ return time.toString( TQt::ISODate ) + 'Z';
}
TQString KolabBase::dateToString( const TQDate& date )
{
- return date.toString( Qt::ISODate );
+ return date.toString( TQt::ISODate );
}
TQDateTime KolabBase::stringToDateTime( const TQString& _date )
@@ -426,12 +426,12 @@ TQDateTime KolabBase::stringToDateTime( const TQString& _date )
//In TQt3, TQt::ISODate cannot handle a trailing Z for UTC, so remove if found.
else if ( date.endsWith( "Z" ) )
date.truncate( date.length() - 1 );
- return TQDateTime::fromString( date, Qt::ISODate );
+ return TQDateTime::fromString( date, TQt::ISODate );
}
TQDate KolabBase::stringToDate( const TQString& date )
{
- return TQDate::fromString( date, Qt::ISODate );
+ return TQDate::fromString( date, TQt::ISODate );
}
TQString KolabBase::sensitivityToString( Sensitivity s )
@@ -58,7 +58,7 @@ KolabBase::~KolabBase()
{
// So far unhandled KCal::IncidenceBase fields:
- // mPilotID, mSyncStatus, mFloats
+ // mPilotID, mSynctqStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );